@@ -34,8 +34,8 @@
 
 #include "modem-prober.h"
 
-#if PY_MAJOR_VERSION >= 3
-#define PyString_FromString PyUnicode_FromString
+#ifndef XCASE
+#define XCASE 0000004
 #endif
 
 static gboolean verbose = FALSE;
@@ -65,9 +65,9 @@ static struct modem_caps modem_caps[] = {
 	{NULL}
 };
 
-#define verbose(fmt, args...) \
+#define verbose(fmt, ...) \
 if (verbose) { \
-	g_print ("%s(): " fmt "\n", G_STRFUNC, ##args); \
+	g_print ("%s(): " fmt "\n", G_STRFUNC, ##__VA_ARGS__); \
 }
 
 static gboolean
@@ -361,7 +361,7 @@ static int modem_probe_caps(int fd, glong timeout_ms)
 		g_free (reply);
 		reply = NULL;
 
-		verbose ("GCAP failed, trying ATI...");
+		verbose ("GCAP failed, trying ATI...%s", "");
 		if (modem_send_command (fd, "ATI\r\n")) {
 			idx = modem_wait_reply (fd, 3, ati_responses, terminators, &term_idx, &reply);
 			if (0 == term_idx && 0 == idx) {
@@ -410,31 +410,31 @@ static gboolean on_finished(gpointer data) {
 			PyObject* name;
 			PyObject* caps = PyList_New(0);
 			if (info->caps & MODEM_CAP_GSM) {
-				name = PyString_FromString("GSM-07.07");
+				name = PyUnicode_FromString("GSM-07.07");
 				PyList_Append(caps, name);
 				Py_XDECREF(name);
 			
-				name = PyString_FromString("GSM-07.05");
+				name = PyUnicode_FromString("GSM-07.05");
 				PyList_Append(caps, name);
 				Py_XDECREF(name);
 			}
 			if (info->caps & MODEM_CAP_IS707_A) {
-				name = PyString_FromString("IS-707-A");
+				name = PyUnicode_FromString("IS-707-A");
 				PyList_Append(caps, name);
 				Py_XDECREF(name);
 			}
 			if (info->caps & MODEM_CAP_IS707_P) {
-				name = PyString_FromString("IS-707-P");
+				name = PyUnicode_FromString("IS-707-P");
 				PyList_Append(caps, name);
 				Py_XDECREF(name);
 			}
 			if (info->caps & MODEM_CAP_IS856) {
-				name = PyString_FromString("IS-856");
+				name = PyUnicode_FromString("IS-856");
 				PyList_Append(caps, name);
 				Py_XDECREF(name);
 			}	
 			if (info->caps & MODEM_CAP_IS856_A) {
-				name = PyString_FromString("IS-856-A");
+				name = PyUnicode_FromString("IS-856-A");
 				PyList_Append(caps, name);
 				Py_XDECREF(name);
 			}	
@@ -461,7 +461,8 @@ static gpointer do_probe(gpointer data) {
 	char* device = info->device;
 
 	struct termios orig, attrs;
-	int fd, caps;
+	int fd = -1;
+	int caps;
 	
 	if (device == NULL) {
 		goto error;
